Changelog
=========

0.1.0
-----
- class name is now 'Zebra' instead of 'zebra'
- Fix for missing win32print module in pypi
- Drop python 2 support
- use setuptools instead of distutils
- improve documentation
- Added reset(), reset_default(), autosense(), print_config_label() and
  print_graphic() functions

0.0.5
-----
- Added -oraw to lpr command to make more CUPS installations work

0.0.4 and earlier
-----------------
Undocumented!
